@@ -18,6 +18,7 @@ from markdown_code_runner import (
     md_comment,
     process_markdown,
     remove_md_comment,
+    update_markdown_file,
 )
 
 TEST_FOLDER = Path(__file__).parent
@@ -200,7 +201,7 @@ def test_main_no_arguments(tmp_path: Path) -> None:
     with patch(
         "argparse.ArgumentParser.parse_args",
         return_value=argparse.Namespace(
-            input=test_filepath,
+            input=[str(test_filepath)],
             output=None,
             verbose=False,
             no_backtick_standardize=True,
@@ -223,7 +224,7 @@ def test_main_filepath_argument(tmp_path: Path) -> None:
     with patch(
         "argparse.ArgumentParser.parse_args",
         return_value=argparse.Namespace(
-            input=test_filepath,
+            input=[str(test_filepath)],
             output=str(output_filepath),
             verbose=False,
             no_backtick_standardize=True,
@@ -246,7 +247,7 @@ def test_main_debug_mode(capfd: pytest.CaptureFixture, tmp_path: Path) -> None:
     with patch(
         "argparse.ArgumentParser.parse_args",
         return_value=argparse.Namespace(
-            input=test_filepath,
+            input=[str(test_filepath)],
             output=str(output_filepath),
             verbose=True,
             no_backtick_standardize=True,
@@ -955,3 +956,193 @@ def test_indented_code_blocks() -> None:
         "    <!-- OUTPUT:END -->",
     ]
     assert_process(input_lines, expected_output, backtick_standardize=False)
+
+
+def test_include_section_function(tmp_path: Path) -> None:
+    """Test the built-in include_section() function."""
+    # Create a source file with sections
+    source_file = tmp_path / "source.md"
+    source_file.write_text(
+        """# Main Title
+
+Some intro text.
+
+<!-- SECTION:intro:START -->
+## Introduction
+
+This is the intro section.
+<!-- SECTION:intro:END -->
+
+<!-- SECTION:features:START -->
+## Features
+
+- Feature 1
+- Feature 2
+<!-- SECTION:features:END -->
+
+Footer text.
+"""
+    )
+
+    # Create a markdown file that uses section()
+    md_file = tmp_path / "test.md"
+    md_file.write_text(
+        """# Test Doc
+
+<!-- CODE:START -->
+<!-- print(include_section("source.md", "intro")) -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+old content
+<!-- OUTPUT:END -->
+"""
+    )
+
+    update_markdown_file(md_file)
+
+    result = md_file.read_text()
+    assert "## Introduction" in result
+    assert "This is the intro section." in result
+    assert "old content" not in result
+
+
+def test_include_section_function_strip_heading(tmp_path: Path) -> None:
+    """Test include_section() with strip_heading=True."""
+    source_file = tmp_path / "source.md"
+    source_file.write_text(
+        """<!-- SECTION:intro:START -->
+## Introduction
+
+This is the intro section.
+<!-- SECTION:intro:END -->
+"""
+    )
+
+    md_file = tmp_path / "test.md"
+    md_file.write_text(
+        """# Test Doc
+
+<!-- CODE:START -->
+<!-- print(include_section("source.md", "intro", strip_heading=True)) -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+old
+<!-- OUTPUT:END -->
+"""
+    )
+
+    update_markdown_file(md_file)
+
+    result = md_file.read_text()
+    assert "## Introduction" not in result
+    assert "This is the intro section." in result
+
+
+def test_include_section_function_not_found(tmp_path: Path) -> None:
+    """Test include_section() raises ValueError when section not found."""
+    source_file = tmp_path / "source.md"
+    source_file.write_text("# No sections here\n")
+
+    md_file = tmp_path / "test.md"
+    md_file.write_text(
+        """<!-- CODE:START -->
+<!-- print(include_section("source.md", "nonexistent")) -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+<!-- OUTPUT:END -->
+"""
+    )
+
+    with pytest.raises(ValueError, match="Section 'nonexistent' not found"):
+        update_markdown_file(md_file)
+
+
+def test_include_section_function_missing_end_marker(tmp_path: Path) -> None:
+    """Test include_section() raises ValueError when end marker is missing."""
+    source_file = tmp_path / "source.md"
+    source_file.write_text(
+        """<!-- SECTION:broken:START -->
+Content without end marker
+"""
+    )
+
+    md_file = tmp_path / "test.md"
+    md_file.write_text(
+        """<!-- CODE:START -->
+<!-- print(include_section("source.md", "broken")) -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+<!-- OUTPUT:END -->
+"""
+    )
+
+    with pytest.raises(ValueError, match="End marker for section 'broken' not found"):
+        update_markdown_file(md_file)
+
+
+def test_main_multiple_files(tmp_path: Path) -> None:
+    """Test the main function with multiple input files."""
+    # Create two test files
+    file1 = tmp_path / "file1.md"
+    file1.write_text(
+        """<!-- CODE:START -->
+<!-- print("file1") -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+old content
+<!-- OUTPUT:END -->
+"""
+    )
+
+    file2 = tmp_path / "file2.md"
+    file2.write_text(
+        """<!-- CODE:START -->
+<!-- print("file2") -->
+<!-- CODE:END -->
+<!-- OUTPUT:START -->
+old content
+<!-- OUTPUT:END -->
+"""
+    )
+
+    with patch(
+        "argparse.ArgumentParser.parse_args",
+        return_value=argparse.Namespace(
+            input=[str(file1), str(file2)],
+            output=None,
+            verbose=False,
+            no_backtick_standardize=True,
+            standardize=False,
+            no_execute=False,
+        ),
+    ):
+        main()
+
+    # Check that both files were processed
+    assert "file1" in file1.read_text()
+    assert "file2" in file2.read_text()
+
+
+def test_main_multiple_files_with_output_error(tmp_path: Path) -> None:
+    """Test that --output with multiple files raises an error."""
+    file1 = tmp_path / "file1.md"
+    file1.write_text("# File 1\n")
+    file2 = tmp_path / "file2.md"
+    file2.write_text("# File 2\n")
+    output = tmp_path / "output.md"
+
+    with (
+        patch(
+            "argparse.ArgumentParser.parse_args",
+            return_value=argparse.Namespace(
+                input=[str(file1), str(file2)],
+                output=str(output),
+                verbose=False,
+                no_backtick_standardize=True,
+                standardize=False,
+                no_execute=False,
+            ),
+        ),
+        pytest.raises(SystemExit),
+    ):
+        main()
